PCB Environment: ParameterTab Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
ParameterTab Class Reference
Inheritance diagram for ParameterTab:

## Public Member Functions
bool | init ()
void | addParameters (const std::map< std::string, Parameter * > &)
void | clear ()

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/UI/ParameterTab.hpp